==> mcp_mesh-0.1.1.tar.gz: mcp_mesh-0.1.1/src/mcp_mesh/agent_server_generated/tests/test_health_api.py <==
# coding: utf-8

from fastapi.testclient import TestClient


from pydantic import StrictStr  # noqa: F401
from typing import Any  # noqa: F401
from mcp_mesh_agent_server.models.agent_health_response import AgentHealthResponse  # noqa: F401
from mcp_mesh_agent_server.models.readiness_response import ReadinessResponse  # noqa: F401


def test_get_agent_health(client: TestClient):
    """Test case for get_agent_health

    Agent health check
    """

    headers = {
    }
    # uncomment below to make a request
    #response = client.request(
    #    "GET",
    #    "/health",
    #    headers=headers,
    #)

    # uncomment below to assert the status code of the HTTP response
    #assert response.status_code == 200


def test_get_agent_liveness(client: TestClient):
    """Test case for get_agent_liveness

    Agent liveness check
    """

    headers = {
    }
    # uncomment below to make a request
    #response = client.request(
    #    "GET",
    #    "/livez",
    #    headers=headers,
    #)

    # uncomment below to assert the status code of the HTTP response
    #assert response.status_code == 200


def test_get_agent_readiness(client: TestClient):
    """Test case for get_agent_readiness

    Agent readiness check
    """

    headers = {
    }
    # uncomment below to make a request
    #response = client.request(
    #    "GET",
    #    "/ready",
    #    headers=headers,
    #)

    # uncomment below to assert the status code of the HTTP response
    #assert response.status_code == 200

==> mcp_mesh-0.1.5.tar.gz: mcp_mesh-0.1.5/src/mcp_mesh/agent_server_generated/tests/test_health_api.py <==
# coding: utf-8

from typing import Any  # noqa: F401

from fastapi.testclient import TestClient
from pydantic import StrictStr  # noqa: F401

from mcp_mesh_agent_server.models.agent_health_response import (  # noqa: F401
    AgentHealthResponse,
)
from mcp_mesh_agent_server.models.readiness_response import (  # noqa: F401
    ReadinessResponse,
)


def test_get_agent_health(client: TestClient):
    """Test case for get_agent_health

    Agent health check
    """

    headers = {}
    # uncomment below to make a request
    # response = client.request(
    #    "GET",
    #    "/health",
    #    headers=headers,
    # )

    # uncomment below to assert the status code of the HTTP response
    # assert response.status_code == 200


def test_get_agent_liveness(client: TestClient):
    """Test case for get_agent_liveness

    Agent liveness check
    """

    headers = {}
    # uncomment below to make a request
    # response = client.request(
    #    "GET",
    #    "/livez",
    #    headers=headers,
    # )

    # uncomment below to assert the status code of the HTTP response
    # assert response.status_code == 200


def test_get_agent_readiness(client: TestClient):
    """Test case for get_agent_readiness

    Agent readiness check
    """

    headers = {}
    # uncomment below to make a request
    # response = client.request(
    #    "GET",
    #    "/ready",
    #    headers=headers,
    # )

    # uncomment below to assert the status code of the HTTP response
    # assert response.status_code == 200
